=======
History
=======

0.1.0 (2019-01-27)
------------------

* First release on PyPI.
* Basic functional CLI client, to allow basic control (on, off, check state)
* Added comprehensive logging with verbosity option to help debug new devices
* Control of device is via async websocket, so should be usable in async code
